==> PhyPraKit-1.1.3.tar.gz: PhyPraKit-1.1.3/README.md <==
*************
**PhyPraKit**
*************


=====
About
=====

PhyPraKit is a collection of python modules `(supporting python 2.7
(deprecated) and python >=3.6)` for data visualization and analysis
in experimental laboratory courses in physics, developed at the
faculty of physics at Karlsruhe Institute of Technology (KIT).
As the modules are intended primarily for use by undergraduate
students in Karlsruhe, the documentation is partly in German
language, in particular the description of the examples.

Created by: 

* Guenter Quast <guenter (dot) quast (at) online (dot) de>

  
Installation:
-------------

To use PhyPraKit, it is sufficient to place the the directory
`PhyPraKit` and all the files in it in the same directory as the
python scripts importing it.

Installation via `pip` is also supported. After downloading, execute: 

``pip install --user .`` 

in the main directory of the *PhyPraKit* package (where *setup.py*
is located) to install in user space.  

The installation using the *whl*-package provided in the subdirectory
`dist` may also be used:

   ``pip install --user --no-cache PhyPraKit<version>.whl``

Installation via the PyPi Python Package Index is also available, simply
execute:
   
   ``pip install --user PhyPraKit``

[Documentaion on "Read the Docs"](https://readthedocs.org/projects/phyprakit/)


Übersicht:
----------

PhyPraKit ist eine Sammlung nützlicher Funktionen in der Sprache 
`Python (vers. 2.7 oder >=3.6)` zum Aufnehmen, zur Bearbeitung, 
Visualisierung  und  Auswertung von Daten in den physikalischen 
Praktika. Die Anwendung der verschiedenen Funktionen des Pakets
werden jeweils durch Beispiele illustriert.

[Dokumentation auf "Read the Docs"](https://readthedocs.org/projects/phyprakit/)

==> PhyPraKit-1.2.3.tar.gz: PhyPraKit-1.2.3/README.md <==
*************
**PhyPraKit**
*************

About
-----

PhyPraKit is a collection of python modules `(supporting python 2.7
(deprecated) and python >=3.6)` for data visualization and analysis
in experimental laboratory courses in physics, developed at the
faculty of physics at Karlsruhe Institute of Technology (KIT).
As the modules are intended primarily for use by undergraduate
students in Karlsruhe, the documentation is partly in German
language, in particular the description of the examples.

Created by: 

* Guenter Quast <guenter (dot) quast (at) online (dot) de>

  
Installation:
-------------

To use PhyPraKit, it is sufficient to place the the directory
`PhyPraKit` and all the files in it in the same directory as the
python scripts importing it.

Installation via `pip` is also supported. After downloading, execute: 

``pip install --user .`` 

in the main directory of the *PhyPraKit* package (where *setup.py*
is located) to install in user space.  

The installation using the *whl*-package provided in the subdirectory
`dist` may also be used:

   ``pip install --user --no-cache PhyPraKit<version>.whl``

Installation via the PyPi Python Package Index is also available, simply
execute:
   
   ``pip install --user PhyPraKit``

[Documentaion on "Read the Docs"](https://readthedocs.org/projects/phyprakit/)


Übersicht:
----------

PhyPraKit ist eine Sammlung nützlicher Funktionen in der Sprache 
`Python (vers. >=3.6, 2.7 noch für manche Module lauffähig)`
zum Aufnehmen, zur Bearbeitung, Visualisierung  und  Auswertung
von Daten in den physikalischen Praktika.
Die Anwendung der verschiedenen Funktionen des Pakets
werden jeweils durch konkrete Beispiele illustriert.

[Dokumentation auf "Read the Docs"](https://readthedocs.org/projects/phyprakit/)
